dcrasterize: rasterize vector data using fasterize

Description Usage Arguments Value

View source: R/dcrasterize.R

Description

Rasterize vector data using fasterize (fast rasterize) function. It creates a raster grid file and seperate attribute table stored in a .rds file. This functions requires a datacube reference (pixid) grid

Usage

1
dcrasterize(obj, layername, attribute, refraster)

Arguments

obj

spatial vector object

layername

name of rasterlayer

attribute

name of attribute to rasterize

refraster

reference raster

Value

this function creates three files in the data directory, two raster files (grd and gri) and a rds file with the attribute table. This function returns a list with the filenames.


jspijker/datacube documentation built on Oct. 26, 2019, 4:30 p.m.