Description Usage Arguments Value
Rasterize vector data using fasterize (fast rasterize) function. It creates a raster grid file and seperate attribute table stored in a .rds file. This functions requires a datacube reference (pixid) grid
1 | dcrasterize(obj, layername, attribute, refraster)
|
obj |
spatial vector object |
layername |
name of rasterlayer |
attribute |
name of attribute to rasterize |
refraster |
reference raster |
this function creates three files in the data directory, two raster files (grd and gri) and a rds file with the attribute table. This function returns a list with the filenames.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.